@@ -154,7 +154,7 @@ class Future(
         """
         return IO(await self._inner_value)
 
-    def map(  # noqa: WPS125
+    def map(
         self,
         function: Callable[[_ValueType], _NewValueType],
     ) -> 'Future[_NewValueType]':
@@ -507,7 +507,7 @@ class FutureResult(
     Use ``Future[a]`` for operations that cannot fail.
 
     This is a ``Future`` that returns ``Result`` type.
-    By providing this utility type we make developers' lifes easier.
+    By providing this utility type we make developers' lives easier.
     ``FutureResult`` has a lot of composition helpers
     to turn complex nested operations into a one function calls.
 
@@ -621,7 +621,7 @@ class FutureResult(
         """
         return FutureResult(_future_result.async_swap(self._inner_value))
 
-    def map(  # noqa: WPS125
+    def map(
         self,
         function: Callable[[_ValueType], _NewValueType],
     ) -> 'FutureResult[_NewValueType, _ErrorType]':
