@@ -1,15 +1,15 @@
 from typing import ClassVar
 
-from returns._internal.pipeline.flow import _flow as flow
+from returns._internal.pipeline.flow import flow as flow
 from returns._internal.pipeline.managed import managed as managed
-from returns._internal.pipeline.pipe import _pipe as pipe
+from returns._internal.pipeline.pipe import pipe as pipe
 from returns.interfaces.unwrappable import Unwrappable
 from returns.primitives.exceptions import UnwrapFailedError
 
 
 def is_successful(container: Unwrappable) -> bool:
     """
-    Determins if a container was successful or not.
+    Determines if a container was successful or not.
 
     .. code:: python
 
